@@ -175,11 +175,15 @@ treeadmin.jQuery(function($){
 					// get out early if items are the same
 					if(cutItem != pastedOn) {
 						var isParent = (moveTo.relativeTo.next().attr('rel') > moveTo.relativeTo.attr('rel'));
+						var position = '';
+
 						// determine position
 						if(moveTo.side == CHILD && !isParent) {
-							var position = 'last-child';
+							position = 'last-child';
+						} else if (moveTo.side == BEFORE) {
+							position = 'left';
 						} else {
-							var position = 'left';
+							position = 'right';
 						}
 
 						// save
